@@ -76,7 +76,8 @@ class Condition:
     vuntil: Optional[List[Union[float, str]]] = None
     steps: Optional[str] = None
     interval: Optional[str] = None
-    direction: Optional[PeriodOperator] = None
+    direction: Optional[Union[PeriodOperator, str]] = None
+    exclusion: Optional[bool] = None
 
     def __repr__(self):
         vars = []
@@ -86,6 +87,13 @@ class Condition:
             formatted_value = "( " + ", ".join(vars) + " )"
         else:
             formatted_value = None
+        vuntils = []
+        if self.vuntil is not None:
+            for vunt in self.vuntil:
+                vuntils.append(str(vunt))
+            formatted_vuntil = "( " + ", ".join(vuntils) + " )"
+        else:
+            formatted_vuntil = None
         if isinstance(self.operator, str):
             operator = self.operator
         else:
@@ -109,10 +117,39 @@ class Condition:
                 field_with_agg = self.field.aggregation + " ( " + field_with_agg + " )"
         else:
             field_with_agg = field_with_agg
-        if formatted_value is not None:
+        if formatted_value is not None and formatted_vuntil is None and self.direction is None:
             where_condition = (
                     field_with_agg + " " + operator + " " + str(formatted_value)
             )
+        elif formatted_value is not None and formatted_vuntil is not None and self.direction is None:
+            where_condition = (
+                    field_with_agg + " " + operator + " " + str(formatted_value) + " " + str(formatted_vuntil)
+            )
+        elif formatted_value is None and formatted_vuntil is not None and self.direction is None:
+            where_condition = (
+                    field_with_agg + " " + operator + " " + str(formatted_vuntil)
+            )
+        elif formatted_value is None and formatted_vuntil is None and self.direction is not None:
+            if isinstance(self.direction, PeriodOperator):
+                direction = self.direction.name
+            else:
+                direction = self.direction
+            if self.steps is not None and self.interval is not None:
+                where_condition = (
+                    field_with_agg + " " + operator + " " + self.interval + " " + direction + " " + self.steps
+                )
+            elif self.steps is not None and self.interval is None:
+                where_condition = (
+                        field_with_agg + " " + operator + " " + direction + " " + self.steps
+                )
+            elif self.steps is None and self.interval is not None:
+                where_condition = (
+                        field_with_agg + " " + operator + " " + self.interval + " " + direction
+                )
+            else:
+                where_condition = (
+                        field_with_agg + " " + operator + " " + direction
+                )
         else:
             where_condition = (
                     field_with_agg + " " + operator
